@@ -2,7 +2,7 @@
 
 """
 Author: Bob Rosbag
-2020
+2022
 
 This plug-in is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -27,16 +27,10 @@ from libqtopensesame.items.qtautoplugin import qtautoplugin
 from libopensesame.exceptions import osexception
 from openexp.keyboard import keyboard
 
-VERSION = u'8.7.0'
+VERSION = u'8.9.0'
 
 class audio_low_latency_play_pause(item):
 
-    """
-    Class handles the basic functionality of the item.
-    It does not deal with GUI stuff.
-    """
-
-    # Provide an informative description for your plug-in.
     description = u'Low Latency Audio: stops the background audio playback.'
 
     def __init__(self, name, experiment, string=None):
@@ -45,17 +39,13 @@ class audio_low_latency_play_pause(item):
         self.verbose = u'no'
         self.poll_time = 100
 
-
     def reset(self):
 
-        """Resets plug-in to initial values."""
         pass
 
 
     def init_var(self):
 
-        """Set en check variables."""
-
         if hasattr(self.experiment, "audio_low_latency_play_dummy_mode"):
             self.dummy_mode = self.experiment.audio_low_latency_play_dummy_mode
             self.verbose = self.experiment.audio_low_latency_play_verbose
@@ -65,12 +55,8 @@ class audio_low_latency_play_pause(item):
 
         self.experiment.audio_low_latency_play_pause = 1
 
-
     def prepare(self):
 
-        """Preparation phase"""
-
-        # Call the parent constructor.
         item.prepare(self)
 
         self.init_var()
@@ -78,11 +64,8 @@ class audio_low_latency_play_pause(item):
         # create keyboard object
         self.kb = keyboard(self.experiment,timeout=1)
 
-
     def run(self):
 
-        """Run phase"""
-
         if not hasattr(self.experiment, "audio_low_latency_play_start"):
             raise osexception(
                     u'Audio Low Latency Play Start item is missing')
@@ -104,12 +87,7 @@ class audio_low_latency_play_pause(item):
         else:
             self.show_message(u'Error with dummy mode!')
 
-
     def show_message(self, message):
-        """
-        desc:
-            Show message.
-        """
 
         debug.msg(message)
         if self.verbose == u'yes':
@@ -120,7 +98,5 @@ class qtaudio_low_latency_play_pause(audio_low_latency_play_pause, qtautoplugin)
 
     def __init__(self, name, experiment, script=None):
 
-        """Plug-in GUI"""
-
         audio_low_latency_play_pause.__init__(self, name, experiment, script)
         qtautoplugin.__init__(self, __file__)
