@@ -2,7 +2,7 @@
 
 """
 Author: Bob Rosbag
-2020
+2022
 
 This plug-in is free software: you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
@@ -30,16 +30,10 @@ import pygame
 import subprocess
 import re
 
-VERSION = u'8.7.0'
+VERSION = u'8.9.0'
 
 class audio_low_latency_record_init(item):
 
-    """
-    Class handles the basic functionality of the item.
-    It does not deal with GUI stuff.
-    """
-
-    # Provide an informative description for your plug-in.
     description = u'Low Latency Audio: initializes the recording audio device.'
     lazy_init = False
 
@@ -50,12 +44,8 @@ class audio_low_latency_record_init(item):
 
         item.__init__(self, name, experiment, string)
 
-
     def reset(self):
 
-        """Resets plug-in to initial values."""
-
-        # Set default experimental variables and values
         self.var.dummy_mode = u'no'
         self.var.verbose = u'no'
         self.var.bitdepth = str(16)
@@ -147,11 +137,8 @@ class audio_low_latency_record_init(item):
         device_list = self.experiment.audio_low_latency_record_device_dict[self.var.module]
         self.var.device_name = device_list[0]
 
-
     def init_var(self):
 
-        """Set en check variables."""
-
         if hasattr(self.experiment, u'audio_low_latency_record_device'):
             if self.experiment.audio_low_latency_record_device:
                 self.experiment.audio_low_latency_record.close()
@@ -205,9 +192,6 @@ class audio_low_latency_record_init(item):
 
     def prepare(self):
 
-        """Preparation phase"""
-
-        # Call the parent constructor.
         item.prepare(self)
         self.close()
         self.init_var()
@@ -419,32 +403,18 @@ class audio_low_latency_record_init(item):
         else:
             self.show_message(u'Error with dummy mode, mode is: %s' % self.dummy_mode)
 
-
     def run(self):
 
-        """Run phase"""
-
         self.set_item_onset()
 
-
     def show_message(self, message):
-        """
-        desc:
-            Show message.
-        """
 
         debug.msg(message)
         if self.verbose == u'yes':
             print(message)
 
-
     def close(self):
 
-        """
-        desc:
-            Neatly close the connection to the parallel port.
-        """
-
         if not hasattr(self.experiment, "audio_low_latency_record_device") or \
             self.experiment.audio_low_latency_record_device is None:
                 self.show_message(u"no active Audio Device")
@@ -467,8 +437,6 @@ class qtaudio_low_latency_record_init(audio_low_latency_record_init, qtautoplugi
 
     def __init__(self, name, experiment, script=None):
 
-        """plug-in GUI"""
-
         audio_low_latency_record_init.__init__(self, name, experiment, script)
         qtautoplugin.__init__(self, __file__)
 
@@ -498,11 +466,6 @@ class qtaudio_low_latency_record_init(audio_low_latency_record_init, qtautoplugi
 
     def apply_edit_changes(self):
 
-        """
-        desc:
-            Applies the controls.
-        """
-
         if not qtautoplugin.apply_edit_changes(self) or self.lock:
             return False
         self.custom_interactions()
@@ -510,13 +473,6 @@ class qtaudio_low_latency_record_init(audio_low_latency_record_init, qtautoplugi
 
     def edit_widget(self):
 
-        """
-        Refreshes the controls.
-
-        Returns:
-        The QWidget containing the controls
-        """
-
         if self.lock:
             return
         self.lock = True
@@ -527,11 +483,6 @@ class qtaudio_low_latency_record_init(audio_low_latency_record_init, qtautoplugi
 
     def custom_interactions(self):
 
-        """
-        desc:
-            Activates the relevant controls for each tracker.
-        """
-
         if self.current_module != self.var.module:
             ## save old device
             old_device_name = self.var.device_name
